summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/aica.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/aica.cpp')
-rw-r--r--src/devices/sound/aica.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/devices/sound/aica.cpp b/src/devices/sound/aica.cpp
index f3ce7c337e0..8d4ef4286cc 100644
--- a/src/devices/sound/aica.cpp
+++ b/src/devices/sound/aica.cpp
@@ -1231,7 +1231,7 @@ s32 aica_device::UpdateSlot(AICA_SLOT *slot)
void aica_device::DoMasterSamples(int nsamples)
{
- stream_sample_t *exts[2];
+ stream_sample_t const *exts[2];
int i;
stream_sample_t *bufr = m_bufferr;
@@ -1390,10 +1390,10 @@ int aica_device::IRQCB(void *param)
#endif
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void aica_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void aica_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
m_bufferl = outputs[0];
m_bufferr = outputs[1];
@@ -1418,7 +1418,7 @@ void aica_device::device_start()
m_irq_cb.resolve_safe();
m_main_irq_cb.resolve_safe();
- m_stream = machine().sound().stream_alloc(*this, 2, 2, (int)m_rate);
+ m_stream = stream_alloc_legacy(2, 2, (int)m_rate);
// save state
save_item(NAME(m_udata.data));
@@ -1390,10 +1390,10 @@ int aica_device::IRQCB(void *param)
#endif
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------